@@ -1,10 +1,19 @@
-tv.veg <- function (db, tv_home, taxval = TRUE, convcode = TRUE, lc = c("layer","mean","max","sum","first"), pseudo = list(lc.1,'LAYER'), values = "COVER_PERC", concept, spcnames = c('short','long','numbers'), dec = 0, cover.transform = c('no', 'pa', 'sqrt'), obs, refl, spc, site, RelScale, sysPath = FALSE, ...) 
+tv.db <- function() {
+  tv_home <- tv.home()
+  dir <- list.dirs(path = file.path(tv_home,'Data'), full.names = FALSE)
+  for (i in 1:length(dir)) dir[i] <- substring(dir[i], nchar(tv_home)+7)
+  return(dir)
+}
+
+
+
+tv.veg <- function (db, tv_home, taxval = TRUE, convcode = TRUE, lc = c("layer","mean","max","sum","first"), pseudo = list(data(lc.1),'LAYER'), values = "COVER_PERC", concept, spcnames = c('short','long','numbers'), dec = 0, cover.transform = c('no', 'pa', 'sqrt'), obs, refl, spc, site, RelScale, ...) 
 {
 ## Checks
     lc <- match.arg(lc)
     cover.transform <- match.arg(cover.transform)
     spcnames = match.arg(spcnames)
-    if(missing(tv_home)) tv_home <- tv.home(sysPath=sysPath)
+    if(missing(tv_home)) tv_home <- tv.home()
     if(missing(obs)) obs <- tv.obs(db, tv_home)
 #     if(suppressWarnings(any(obs < -1e+05, na.rm = TRUE))) 
 #       cat("\n WARNING! Values less than -100,000. \n WARNING! tvabund.dbf may be corrupt. \n WARNING! Please correct by reexporting e.g. with OpenOffice.")
@@ -13,18 +22,17 @@ tv.veg <- function (db, tv_home, taxval = TRUE, convcode = TRUE, lc = c("layer",
       obs <- obs[obs$SPECIES_NR %in% spc,]
       }
 ## Taxa
-    if(missing(refl)) refl <- tv.refl(db[1], tv_home = tv_home, sysPath=sysPath)
+    if(missing(refl)) refl <- tv.refl(db[1], tv_home = tv_home)
     cat('Taxonomic reference list: ',refl, '\n')
     if(taxval) 
-	obs <- taxval(obs=obs, refl = refl, sysPath = sysPath, ...)
+	obs <- taxval(obs=obs, refl = refl, ...)
 ## CoverCode
     if(convcode){
         cat('\n converting cover code ... \n')
         if(missing(RelScale)) {     
-          RelScale <- tv.site(db, tv_home=tv_home, quiet = TRUE, sysPath, iconv=NULL)[, c("RELEVE_NR", "COVERSCALE")]
+          RelScale <- tv.site(db, tv_home=tv_home, quiet = TRUE, iconv=NULL)[, c("RELEVE_NR", "COVERSCALE")]
           obs <- tv.coverperc(obs=obs, RelScale = RelScale, tv_home = tv_home, ...) 
-          } else  {obs <- tv.coverperc(db[1], obs, tv_home = tv_home, ...)
-             }
+          } else  obs <- tv.coverperc(db[1], obs, tv_home = tv_home, ...)
       } else {
       if (!any(names(obs) == values)) stop(paste(values, " could not be found.")) 
           obs[,values] <- type.convert(as.character(obs[,values]))
@@ -34,7 +42,8 @@ tv.veg <- function (db, tv_home, taxval = TRUE, convcode = TRUE, lc = c("layer",
 ## Pseudo-Species / Layer
     if(!is.null(pseudo)) {
         cat('\n creating pseudo-species ... \n')
-	if(length(pseudo[[2]]) > 1) stop('Function to differentiate more than one species-plot attribute not yet implemented. Please contact jansen@uni-greifswald.de.')
+	if(length(pseudo[[2]]) > 1) stop('Possibility to differentiate more than one species-plot attribute not yet implemented. \n
+		Please contact <jansen@uni-greifswald.de>.')
         obs$COMB <- pseudo[[1]][, 2][match(obs[, pseudo[[2]]], pseudo[[1]][,1])]
         collab <- paste(obs$SPECIES_NR, obs$COMB, sep = ".")
     } else     collab <- as.vector(obs$SPECIES_NR)
@@ -53,13 +62,13 @@ tv.veg <- function (db, tv_home, taxval = TRUE, convcode = TRUE, lc = c("layer",
     if(spcnames %in% c('short','long')) {
       cat('\n replacing species numbers with ', spcnames, ' names ... \n')
       if(is.null(pseudo)) {
-	species <- tax(as.numeric(colnames(results)), verbose=FALSE, syn=FALSE, refl = refl, tv_home=tv_home, sysPath=sysPath, ...)
+	species <- tax(as.numeric(colnames(results)), verbose=FALSE, syn=FALSE, refl = refl, tv_home=tv_home, ...)
 	if(spcnames=='short') colnames(results) <- species$LETTERCODE[match(colnames(results), species$SPECIES_NR)]
 	if(spcnames=='long') colnames(results) <- gsub(' ','_', species$ABBREVIAT[match(colnames(results), species$SPECIES_NR)] )
         } else {
 	st <- unlist(strsplit(colnames(results), ".", fixed = TRUE))
 	colspc <- st[seq(1, length(st), 2)]
-	species <- tax(as.numeric(colspc), verbose=FALSE, refl = refl, tv_home=tv_home, sysPath=sysPath, ...)
+	species <- tax(as.numeric(colspc), verbose=FALSE, refl = refl, tv_home=tv_home, ...)
 	ll <- st[seq(2, length(st), 2)]
 	if(spcnames=='short') coln <- as.character(species$LETTERCODE[match(as.numeric(colspc), species$SPECIES_NR)])
 	if(spcnames=='long') coln <- gsub(' ','_', species$ABBREVIAT[match(as.numeric(colspc), species$SPECIES_NR)]) 
@@ -76,6 +85,7 @@ tv.veg <- function (db, tv_home, taxval = TRUE, convcode = TRUE, lc = c("layer",
       if(cover.transform == 'sqrt') results <- as.data.frame(round(sqrt(results),dec))
    }
       class(results) <- c("veg", "data.frame")
+      attr(results, 'taxreflist') <- refl
    return(results)
 }
 
@@ -85,7 +95,7 @@ first.word <- function (x, i = 1, expr = substitute(x)) {
     if (i > 1) stop("i > 1 not implemented")
     chars <- substring(words, 1:nchar(words), 1:nchar(words))
     legal.chars <- c(letters, LETTERS, ".", "0", "1", "2", "3", "4", "5", "6", "7", "8", "9")
-    non.legal.chars <- (1:length(chars))[chars %nin% legal.chars]
+    non.legal.chars <- (1:length(chars))[chars %in% legal.chars]
     if (!any(non.legal.chars)) return(words)
     if (non.legal.chars[1] == 1) return(character(0))
     substring(words, 1, non.legal.chars[1] - 1)
